﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using SalesforceAPI.Models;

namespace SalesforceAPI.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class CustomerCsController : ControllerBase
    {
        private readonly CustomerContext _context;

        public CustomerCsController(CustomerContext context)
        {
            _context = context;
        }

        // GET: api/CustomerCs
        [HttpGet]
        public async Task<ActionResult<IEnumerable<CustomerC>>> GetCustomerC()
        {
            return await _context.CustomerC.ToListAsync();
        }

        // GET: api/CustomerCs/5
        [HttpGet("{id}")]
        public async Task<ActionResult<CustomerC>> GetCustomerC(string id)
        {
            var customerC = await _context.CustomerC.FindAsync(id);

            if (customerC == null)
            {
                return NotFound();
            }

            return customerC;
        }

        // PUT: api/CustomerCs/5
        // To protect from overposting attacks, enable the specific properties you want to bind to, for
        // more details, see https://go.microsoft.com/fwlink/?linkid=2123754.
        [HttpPut("{id}")]
        public async Task<IActionResult> PutCustomerC(string id, CustomerC customerC)
        {
            if (id != customerC.Id)
            {
                return BadRequest();
            }

            _context.Entry(customerC).State = EntityState.Modified;

            try
            {
                await _context.SaveChangesAsync();
            }
            catch (DbUpdateConcurrencyException)
            {
                if (!CustomerCExists(id))
                {
                    return NotFound();
                }
                else
                {
                    throw;
                }
            }

            return NoContent();
        }

        // POST: api/CustomerCs
        // To protect from overposting attacks, enable the specific properties you want to bind to, for
        // more details, see https://go.microsoft.com/fwlink/?linkid=2123754.
        [HttpPost]
        public async Task<ActionResult<CustomerC>> PostCustomerC(CustomerC customerC)
        {
            _context.CustomerC.Add(customerC);
            await _context.SaveChangesAsync();

            return CreatedAtAction("GetCustomerC", new { id = customerC.Id }, customerC);
        }

        // DELETE: api/CustomerCs/5
        [HttpDelete("{id}")]
        public async Task<ActionResult<CustomerC>> DeleteCustomerC(string id)
        {
            var customerC = await _context.CustomerC.FindAsync(id);
            if (customerC == null)
            {
                return NotFound();
            }

            _context.CustomerC.Remove(customerC);
            await _context.SaveChangesAsync();

            return customerC;
        }

        private bool CustomerCExists(string id)
        {
            return _context.CustomerC.Any(e => e.Id == id);
        }
    }
}
